@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: adjunctions
 version: 4.3
-id: adjunctions-4.3-c475a106420800be166b9b6982c59446
-key: adjun_0qyiUsQIKFUKOnkWyF145T
+id: adjunctions-4.3-51e7d4a24d361113244a76d085504c45
+key: adjun_4sJkfnsClao8vrjouiehAW
 license: BSD3
 copyright: Copyright (C) 2011-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,18 +26,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
-hs-libraries: HSadjunctions-4.3-0qyiUsQIKFUKOnkWyF145T
+hs-libraries: HSadjunctions-4.3-4sJkfnsClao8vrjouiehAW
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-e98e7adc8875accf64a86529d9aeae51
+    comonad-5-3b2e208311908bc5a9db1ceb26126917
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
-    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
-    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
+    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
+    free-4.12.4-f8dab736d0d811e91eb50084b5673f3a
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
-    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    profunctors-5.2-026a1eb9905bccdb097d36481584da83
+    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
